# p5-python-new_service_port_generator
Random port generator for new tcp/udp service

# Install
`pip install p5.new-service-port-generator` or call `pip install .` in source directory
```
Processing /home/user/src/python-new_service_port_generator
Installing collected packages: p5.new-service-port-generator
  Running setup.py install for p5.new-service-port-generator ... done
Successfully installed p5.new-service-port-generator-0.0.2
```

# Uninstall
`pip uninstall p5.new-service-port-generator`
```
Uninstalling p5.new-service-port-generator-0.0.0:
  Would remove:
    /home/user/src/python-new_service_port_generator/venv/lib/python3.8/site-packages/p5.new_service_port_generator-0.0.0-py3.8.egg-info
    /home/user/src/python-new_service_port_generator/venv/lib/python3.8/site-packages/p5/new_service_port_generator/*
Proceed (y/n)? y
  Successfully uninstalled p5.new-service-port-generator-0.0.2
```

# Example
[call this: `example.py`](./example.py)
